"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var chai_1 = require("chai");
var access_control_authorization_1 = require("./access-control.authorization");
var logger_1 = require("../logger");
describe('[Access Control]', function () {
    var accessControll;
    var newVideo, myVideo, videoFromThirdPary, adminUser, normalUser, guestUser;
    var queryMock;
    accessControll = new access_control_authorization_1.CrudAccessControl('video', [
        { role: 'guest', resource: 'catalog', action: 'read:any', attributes: ['*'] },
        { role: 'admin', resource: 'video', action: 'create:any', attributes: ['*'] },
        { role: 'admin', resource: 'video', action: 'read:any', attributes: ['*'] },
        { role: 'admin', resource: 'video', action: 'update:any', attributes: ['*'] },
        { role: 'admin', resource: 'video', action: 'delete:any', attributes: ['*'] },
        { role: 'user', resource: 'video', action: 'create:own', attributes: ['*'] },
        { role: 'user', resource: 'video', action: 'read:any', attributes: ['*'] },
        { role: 'user', resource: 'video', action: 'update:own', attributes: ['*'] },
        { role: 'user', resource: 'video', action: 'delete:own', attributes: ['*'] }
    ]);
    adminUser = {
        _id: '001',
        roles: ['admin']
    };
    normalUser = {
        _id: '100',
        roles: ['user']
    };
    guestUser = {
        _id: '200',
        roles: ['guest']
    };
    newVideo = {
        title: 'Star Wars Episode IX',
    };
    myVideo = {
        title: 'Fight Club',
        owner: { userId: "001" }
    };
    videoFromThirdPary = {
        title: 'The Godfather',
        owner: { userId: "301" }
    };
    queryMock = {
        where: { or: function () { } }
    };
    it('admin should be allowed to create video', function () {
        var req = {
            user: adminUser
        };
        return accessControll.checkCreate(req)
            .then(function (check) {
            chai_1.expect(check.isGranted).to.equal(true);
            //do not overwrite owner
            chai_1.expect(check.setBeforeUpdate(videoFromThirdPary).owner.userId).to.equal('301');
        });
    });
    it('user should be allowed to create video of its own', function () {
        var req = {
            user: normalUser
        };
        return accessControll.checkCreate(req)
            .then(function (check) {
            chai_1.expect(check.isGranted).to.equal(true);
            logger_1.default.trace(check.setBeforeUpdate(newVideo));
            chai_1.expect(check.setBeforeUpdate(newVideo).owner.userId).to.equal('100');
        });
    });
    it('guest should not be allowed to create video', function () {
        var req = {
            user: guestUser
        };
        return accessControll.checkCreate(req)
            .then(function (check) {
            throw new Error('test failure');
        }).catch(function (err) {
            chai_1.expect(err.message).to.equal("user has no permission to create video");
        });
    });
    it('admin should be allowed to update any video', function () {
        var req = {
            user: adminUser
        };
        return accessControll.checkUpdate(req)
            .then(function (check) {
            chai_1.expect(check.isGranted).to.equal(true);
            //expect(check.applyQueryRestriction({})).to.be.empty;
        });
    });
    it('user should be allowed to update its own video', function () {
        var req = {
            user: normalUser
        };
        return accessControll.checkUpdate(req)
            .then(function (check) {
            chai_1.expect(check.isGranted).to.equal(true);
        });
    });
});
