'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
var Q = require('q');
var logger_1 = require("../logger");
var _ = require("lodash");
function applyUpdate(updates) {
    return function (entity) {
        if (!entity)
            return;
        var updated = entity.merge(updates);
        return updated.save()
            .then(function (result) {
            return result;
        });
    };
}
exports.applyUpdate = applyUpdate;
function applyPatch(patches) {
    return function (entity) {
        if (!_.isArray(patches)) {
            logger_1.default.warn('trying to apply patches, but patches are not an array!');
            patches = [patches];
        }
        return patchAsPromised(entity, patches)
            .then(function (result) {
            logger_1.default.trace(result);
            return result;
        });
    };
}
exports.applyPatch = applyPatch;
function patchAsPromised(entity, patches) {
    var def = Q.defer();
    entity.patch(patches, function callback(err, result, number) {
        if (err) {
            logger_1.default.trace("patch rejected " + err);
            def.reject(err);
        }
        logger_1.default.trace("patched documents " + number);
        def.resolve(result.toObject());
    });
    return def.promise;
}
function removeEntity() {
    return function (entity) {
        if (!entity)
            return;
        return entity.remove()
            .then(function (removed) {
            return removed;
        });
    };
}
exports.removeEntity = removeEntity;
function createEntity(model) {
    return function (entity) {
        return model.create(entity);
    };
}
exports.createEntity = createEntity;
function findEntityById(model, id) {
    return model.findById(id)
        .exec();
}
exports.findEntityById = findEntityById;
